summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSimon McVittie <smcv@collabora.com>2022-02-25 13:45:10 +0000
committerSimon McVittie <smcv@collabora.com>2022-02-25 14:17:01 +0000
commit5c46e9706873caf51f09972e7910e35091bd007f (patch)
tree938af096827f7008596f35f6939e202a22d08561
parentbabbb437c293e2ceddb76daa2921946ea0f4f2e4 (diff)
downloaddbus-5c46e9706873caf51f09972e7910e35091bd007f.tar.gz
CI: Remove EOL versions of Debian and Ubuntu
Debian 9 'stretch' is EOL, and Ubuntu 16.04 is EOL unless you enter into a special subscription with Canonical. This puts them outside our informal security-support policy, and realistically, anyone sufficiently change-averse to be following these distributions is not going to be backporting a current version of dbus. Signed-off-by: Simon McVittie <smcv@collabora.com> (cherry picked from commit 69c610f6f084a3f68994043d2bf11f18016e8052)
-rw-r--r--.gitlab-ci.yml17
-rwxr-xr-xtools/ci-build.sh15
-rwxr-xr-xtools/ci-install.sh59
3 files changed, 9 insertions, 82 deletions
diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
index f2e72653..dd7c4c6b 100644
--- a/.gitlab-ci.yml
+++ b/.gitlab-ci.yml
@@ -120,21 +120,4 @@ x86_64-w64-mingw32-cmake-debug:
ci_variant: "debug"
script: *script
-stretch:
- when: manual
- stage: build
- image: "debian:stretch-slim"
- variables:
- ci_suite: "stretch"
- script: *script
-
-xenial:
- when: manual
- stage: build
- image: "ubuntu:xenial"
- variables:
- ci_distro: "ubuntu"
- ci_suite: "xenial"
- script: *script
-
# vim:set sw=2 sts=2 et:
diff --git a/tools/ci-build.sh b/tools/ci-build.sh
index cfb7fb55..0ca33d96 100755
--- a/tools/ci-build.sh
+++ b/tools/ci-build.sh
@@ -267,18 +267,9 @@ case "$ci_buildsys" in
${make} install DESTDIR=$(pwd)/DESTDIR
( cd DESTDIR && find . -ls )
- case "$ci_suite" in
- (jessie|xenial|stretch)
- # these are too old for maintainer-upload-docs
- ;;
-
- (*)
- # assume Ubuntu 18.04 'bionic', Debian 10 'buster' or newer
- ${make} -C doc dbus-docs.tar.gz
- tar -C $(pwd)/DESTDIR -xf doc/dbus-docs.tar.gz
- ( cd DESTDIR/dbus-docs && find . -ls )
- ;;
- esac
+ ${make} -C doc dbus-docs.tar.gz
+ tar -C $(pwd)/DESTDIR -xf doc/dbus-docs.tar.gz
+ ( cd DESTDIR/dbus-docs && find . -ls )
if [ "$ci_sudo" = yes ] && [ "$ci_test" = yes ]; then
sudo ${make} install
diff --git a/tools/ci-install.sh b/tools/ci-install.sh
index 8ebfa7c3..21548cf5 100755
--- a/tools/ci-install.sh
+++ b/tools/ci-install.sh
@@ -54,9 +54,9 @@ NULL=
# ci_suite:
# OS suite (release, branch) in which we are testing.
# Typical values for ci_distro=debian: sid, jessie
# Typical values for ci_distro=fedora might be 25, rawhide
-: "${ci_suite:=xenial}"
+: "${ci_suite:=bullseye}"
# ci_variant:
# One of debug, reduced, legacy, production
@@ -87,30 +87,6 @@ case "$ci_distro" in
$sudo sed -i -e 's/httpredir\.debian\.org/deb.debian.org/g' \
/etc/apt/sources.list
- case "$ci_suite" in
- (xenial)
- # Ubuntu 16.04 didn't have the wine32, wine64 packages
- wine32=wine:i386
- wine64=wine:amd64
- ;;
- (*)
- wine32=wine32
- wine64=wine64
- ;;
- esac
-
- case "$ci_suite" in
- (trusty)
- # Ubuntu 14.04 didn't have the wine32, wine64 packages
- wine32=wine:i386
- wine64=wine:amd64
- ;;
- (*)
- wine32=wine32
- wine64=wine64
- ;;
- esac
-
case "$ci_host" in
(i686-w64-mingw32)
$sudo dpkg --add-architecture i386
@@ -129,7 +105,7 @@ case "$ci_distro" in
"${packages[@]}"
binutils-mingw-w64-i686
g++-mingw-w64-i686
- $wine32 wine
+ wine32 wine
)
;;
(x86_64-w64-mingw32)
@@ -137,7 +113,7 @@ case "$ci_distro" in
"${packages[@]}"
binutils-mingw-w64-x86-64
g++-mingw-w64-x86-64
- $wine64 wine
+ wine64 wine
)
;;
esac
@@ -166,6 +142,7 @@ case "$ci_distro" in
docbook-xsl
doxygen
dpkg-dev
+ ducktype
g++
gcc
gnome-desktop-testing
@@ -187,23 +164,10 @@ case "$ci_distro" in
xmlto
xsltproc
xvfb
+ yelp-tools
zstd
)
- case "$ci_suite" in
- (stretch)
- # Debian 9 'stretch' didn't have the ducktype package
- ;;
-
- (*)
- # assume Ubuntu 18.04 'bionic', Debian 10 'buster' or newer
- packages=(
- "${packages[@]}"
- ducktype yelp-tools
- )
- ;;
- esac
-
$sudo apt-get -qq -y --no-install-recommends install "${packages[@]}"
if [ "$ci_in_docker" = yes ]; then
@@ -214,17 +178,6 @@ case "$ci_distro" in
chmod 0440 /etc/sudoers.d/nopasswd
fi
- # manual package setup
- case "$ci_suite" in
- (jessie|xenial)
- # autoconf-archive in Debian 8 and Ubuntu 16.04 is too old,
- # use the one from Debian 9 instead
- wget http://deb.debian.org/debian/pool/main/a/autoconf-archive/autoconf-archive_20160916-1_all.deb
- $sudo dpkg -i autoconf-archive_*_all.deb
- rm autoconf-archive_*_all.deb
- ;;
- esac
-
# Make sure we have a messagebus user, even if the dbus package
# isn't installed
$sudo adduser --system --quiet --home /nonexistent --no-create-home \
@@ -54,9 +54,9 @@ NULL=
# ci_suite:
# OS suite (release, branch) in which we are testing.
-# Typical values for ci_distro=debian: sid, jessie
+# Typical values for ci_distro=debian: sid, bullseye
# Typical values for ci_distro=fedora might be 25, rawhide